#!/bin/sh

#_____________________________________________________________________________#
#                                                                             #
#                        Copyright (C) 2005 - 2021 by                         #
#                    -- TEC-IT Datenverarbeitung GmbH --                      #
#   -- team for engineering and consulting in information technologies --     #
#                                                                             #
#                            All rights reserved.                             #
#_____________________________________________________________________________#
#                                                                             #

#______________________________________________________________________________
#
# Filter printjob file with tbarcodefilter and send result to stdout.  
#______________________________________________________________________________
#

#
# if $6 is empty then printjob is read from stdin
# otherwise parameter $6 contains filename of printjob
#

exitvalue=

if test -z $6
then
  # no filename specified
  # => read from stdin

  /usr/local/share/tbarcode11/tbarcode --filter <&0 >&1
  exitvalue=$?
  
else
  # filename specified
  # => read from file
  
  # make a temporary file for the output of tbarcodefilter
  FILTEREDFILE=`mktemp /tmp/tbarcodefilter.$$.XXXXXX`
  
  /usr/local/share/tbarcode11/tbarcode --filter <$6 >$FILTEREDFILE
  
  exitvalue=$?
  
  # create copies based upon argv[4] (cups.org/doc/api-filter.hmtl)

  COPIES=$4
  while [ $COPIES -gt 0 ]
  do
    cat $FILTEREDFILE
    COPIES=`expr $COPIES - 1`
  done

  # remove FILTEREDFILE file
  rm $FILTEREDFILE
  
fi

# barcode error - don't break CUPS processing
if $exitvalue -eq 70
then
  exitvalue=0
fi

exit $exitvalue
